@@ -5,6 +5,8 @@ from .cp_word import CPWordEncoding
 from .mumidi import MuMIDIEncoding
 from .octuple import OctupleEncoding
 from .octuple_mono import OctupleMonoEncoding
-from .midi_tokenizer_base import get_midi_programs, quantize_note_times, detect_chords, merge_tracks, MIDITokenizer
+from .midi_tokenizer_base import MIDITokenizer, get_midi_programs, detect_chords, merge_tracks, \
+    merge_same_program_tracks
+from .vocabulary import Vocabulary, Event
 from .constants import MIDI_INSTRUMENTS, INSTRUMENT_CLASSES, INSTRUMENT_CLASSES_RANGES, CHORD_MAPS, DRUM_SETS,\
     CONTROL_CHANGES
